@@ -24,49 +24,16 @@ logger = logging.getLogger(__name__)
 
 
 #: Minimum version of tmux required to run libtmux
-TMUX_MIN_VERSION = "1.8"
+TMUX_MIN_VERSION = "3.2a"
 
 #: Most recent version of tmux supported
 TMUX_MAX_VERSION = "3.6"
 
-#: Minimum version before deprecation warning is shown
-TMUX_SOFT_MIN_VERSION = "3.2a"
-
 SessionDict = dict[str, t.Any]
 WindowDict = dict[str, t.Any]
 WindowOptionDict = dict[str, t.Any]
 PaneDict = dict[str, t.Any]
 
-#: Flag to ensure deprecation warning is only shown once per process
-_version_deprecation_checked: bool = False
-
-
-def _check_deprecated_version(version: LooseVersion) -> None:
-    """Check if tmux version is deprecated and warn once.
-
-    This is called from get_version() on first invocation.
-    """
-    global _version_deprecation_checked
-    if _version_deprecation_checked:
-        return
-    _version_deprecation_checked = True
-
-    import os
-    import warnings
-
-    if os.environ.get("LIBTMUX_SUPPRESS_VERSION_WARNING"):
-        return
-
-    if version < LooseVersion(TMUX_SOFT_MIN_VERSION):
-        warnings.warn(
-            f"tmux {version} is deprecated and will be unsupported in a future "
-            f"libtmux release. Please upgrade to tmux {TMUX_SOFT_MIN_VERSION} "
-            "or newer. Set LIBTMUX_SUPPRESS_VERSION_WARNING=1 to suppress this "
-            "warning.",
-            FutureWarning,
-            stacklevel=4,
-        )
-
 
 class EnvironmentMixin:
     """Mixin for manager session and server level environment variables in tmux."""
@@ -321,7 +288,7 @@ def get_version() -> LooseVersion:
                 return LooseVersion(f"{TMUX_MAX_VERSION}-openbsd")
             msg = (
                 f"libtmux supports tmux {TMUX_MIN_VERSION} and greater. This system"
-                " is running tmux 1.3 or earlier."
+                " does not meet the minimum tmux version requirement."
             )
             raise exc.LibTmuxException(
                 msg,
@@ -336,9 +303,7 @@ def get_version() -> LooseVersion:
 
     version = re.sub(r"[a-z-]", "", version)
 
-    version_obj = LooseVersion(version)
-    _check_deprecated_version(version_obj)
-    return version_obj
+    return LooseVersion(version)
 
 
 def has_version(version: str) -> bool:
@@ -347,7 +312,7 @@ def has_version(version: str) -> bool:
     Parameters
     ----------
     version : str
-        version number, e.g. '1.8'
+        version number, e.g. '3.2a'
 
     Returns
     -------
@@ -363,7 +328,7 @@ def has_gt_version(min_version: str) -> bool:
     Parameters
     ----------
     min_version : str
-        tmux version, e.g. '1.8'
+        tmux version, e.g. '3.2a'
 
     Returns
     -------
@@ -379,7 +344,7 @@ def has_gte_version(min_version: str) -> bool:
     Parameters
     ----------
     min_version : str
-        tmux version, e.g. '1.8'
+        tmux version, e.g. '3.2a'
 
     Returns
     -------
@@ -395,7 +360,7 @@ def has_lte_version(max_version: str) -> bool:
     Parameters
     ----------
     max_version : str
-        tmux version, e.g. '1.8'
+        tmux version, e.g. '3.2a'
 
     Returns
     -------
@@ -411,7 +376,7 @@ def has_lt_version(max_version: str) -> bool:
     Parameters
     ----------
     max_version : str
-        tmux version, e.g. '1.8'
+        tmux version, e.g. '3.2a'
 
     Returns
     -------
@@ -422,7 +387,7 @@ def has_lt_version(max_version: str) -> bool:
 
 
 def has_minimum_version(raises: bool = True) -> bool:
-    """Return True if tmux meets version requirement. Version >1.8 or above.
+    """Return True if tmux meets version requirement. Version >= 3.2a.
 
     Parameters
     ----------
@@ -441,6 +406,9 @@ def has_minimum_version(raises: bool = True) -> bool:
 
     Notes
     -----
+    .. versionchanged:: 0.49.0
+        Minimum version bumped to 3.2a. For older tmux, use libtmux v0.48.x.
+
     .. versionchanged:: 0.7.0
         No longer returns version, returns True or False
 
@@ -454,7 +422,7 @@ def has_minimum_version(raises: bool = True) -> bool:
             msg = (
                 f"libtmux only supports tmux {TMUX_MIN_VERSION} and greater. This "
                 f"system has {get_version()} installed. Upgrade your tmux to use "
-                "libtmux."
+                "libtmux, or use libtmux v0.48.x for older tmux versions."
             )
             raise exc.VersionTooLow(msg)
         return False
@@ -488,17 +456,12 @@ def session_check_name(session_name: str | None) -> None:
 def handle_option_error(error: str) -> type[exc.OptionError]:
     """Raise exception if error in option command found.
 
-    In tmux 3.0, show-option and show-window-option return invalid option instead of
-    unknown option. See https://github.com/tmux/tmux/blob/3.0/cmd-show-options.c.
-
-    In tmux >2.4, there are 3 different types of option errors:
+    There are 3 different types of option errors:
 
     - unknown option
     - invalid option
     - ambiguous option
 
-    In tmux <2.4, unknown option was the only option.
-
     All errors raised will have the base error of :exc:`exc.OptionError`. So to
     catch any option error, use ``except exc.OptionError``.
 
