@@ -1,5 +1,7 @@
 """Test for libtmux Session object."""
 
+from __future__ import annotations
+
 import logging
 import shutil
 import typing as t
@@ -7,13 +9,15 @@ import typing as t
 import pytest
 
 from libtmux import exc
-from libtmux.common import has_gte_version, has_lt_version
 from libtmux.pane import Pane
-from libtmux.server import Server
 from libtmux.session import Session
-from libtmux.test import TEST_SESSION_PREFIX, namer
+from libtmux.test.constants import TEST_SESSION_PREFIX
+from libtmux.test.random import namer
 from libtmux.window import Window
 
+if t.TYPE_CHECKING:
+    from libtmux.server import Server
+
 logger = logging.getLogger(__name__)
 
 
@@ -22,9 +26,8 @@ def test_has_session(server: Server, session: Session) -> None:
     TEST_SESSION_NAME = session.get("session_name")
     assert TEST_SESSION_NAME is not None
     assert server.has_session(TEST_SESSION_NAME)
-    if has_gte_version("2.1"):
-        assert not server.has_session(TEST_SESSION_NAME[:-2])
-        assert server.has_session(TEST_SESSION_NAME[:-2], exact=False)
+    assert not server.has_session(TEST_SESSION_NAME[:-2])
+    assert server.has_session(TEST_SESSION_NAME[:-2], exact=False)
     assert not server.has_session("asdf2314324321")
 
 
@@ -48,8 +51,7 @@ def test_select_window(session: Session) -> None:
     assert isinstance(selected_window1, Window)
     attached_window1 = session.attached_window
 
-    assert selected_window1 == attached_window1
-    assert selected_window1.__dict__ == attached_window1.__dict__
+    assert selected_window1.id == attached_window1.id
 
     # again: tmux selects a window, moves to it, shows it as
     # attached_window
@@ -57,12 +59,10 @@ def test_select_window(session: Session) -> None:
     assert isinstance(selected_window2, Window)
     attached_window2 = session.attached_window
 
-    assert selected_window2 == attached_window2
-    assert selected_window2.__dict__ == attached_window2.__dict__
+    assert selected_window2.id == attached_window2.id
 
     # assure these windows were really different
-    assert selected_window1 != selected_window2
-    assert selected_window1.__dict__ != selected_window2.__dict__
+    assert selected_window1.id != selected_window2.id
 
 
 def test_select_window_returns_Window(session: Session) -> None:
@@ -146,11 +146,8 @@ def test_empty_session_option_returns_None(session: Session) -> None:
 
 
 def test_show_option_unknown(session: Session) -> None:
-    """Session.show_option raises UnknownOption for invalid option."""
-    cmd_exception: t.Type[exc.OptionError] = exc.UnknownOption
-    if has_gte_version("3.0"):
-        cmd_exception = exc.InvalidOption
-    with pytest.raises(cmd_exception):
+    """Session.show_option raises InvalidOption for invalid option."""
+    with pytest.raises(exc.InvalidOption):
         session.show_option("moooz")
 
 
@@ -167,19 +164,15 @@ def test_set_option_ambiguous(session: Session) -> None:
 
 
 def test_set_option_invalid(session: Session) -> None:
-    """Session.set_option raises UnknownOption for invalid option."""
-    if has_gte_version("2.4"):
-        with pytest.raises(exc.InvalidOption):
-            session.set_option("afewewfew", 43)
-    else:
-        with pytest.raises(exc.UnknownOption):
-            session.set_option("afewewfew", 43)
+    """Session.set_option raises InvalidOption for invalid option."""
+    with pytest.raises(exc.InvalidOption):
+        session.set_option("afewewfew", 43)
 
 
 def test_show_environment(session: Session) -> None:
     """Session.show_environment() returns dict."""
-    _vars = session.show_environment()
-    assert isinstance(_vars, dict)
+    vars_ = session.show_environment()
+    assert isinstance(vars_, dict)
 
 
 def test_set_show_environment_single(session: Session) -> None:
@@ -217,7 +210,7 @@ def test_unset_environment(session: Session) -> None:
 
 
 @pytest.mark.parametrize(
-    "session_name,raises",
+    ("session_name", "raises"),
     [("hey.period", True), ("hey:its a colon", True), ("hey moo", False)],
 )
 def test_periods_raise_badsessionname(
@@ -262,10 +255,6 @@ def test_cmd_inserts_session_id(session: Session) -> None:
     assert cmd.cmd[-1] == last_arg
 
 
-@pytest.mark.skipif(
-    has_lt_version("3.0"),
-    reason="needs -e flag for new-window which was introduced in 3.0",
-)
 @pytest.mark.parametrize(
     "environment",
     [
@@ -275,7 +264,7 @@ def test_cmd_inserts_session_id(session: Session) -> None:
 )
 def test_new_window_with_environment(
     session: Session,
-    environment: t.Dict[str, str],
+    environment: dict[str, str],
 ) -> None:
     """Verify new window with environment vars."""
     env = shutil.which("env")
@@ -292,27 +281,3 @@ def test_new_window_with_environment(
     for k, v in environment.items():
         pane.send_keys(f"echo ${k}")
         assert pane.capture_pane()[-2] == v
-
-
-@pytest.mark.skipif(
-    has_gte_version("3.0"),
-    reason="3.0 has the -e flag on new-window",
-)
-def test_new_window_with_environment_logs_warning_for_old_tmux(
-    session: Session,
-    caplog: pytest.LogCaptureFixture,
-) -> None:
-    """Verify new window with environment vars create a warning if tmux is too old."""
-    env = shutil.which("env")
-    assert env is not None, "Cannot find usable `env` in PATH."
-
-    session.new_window(
-        attach=True,
-        window_name="window_with_environment",
-        window_shell=f"{env} PS1='$ ' sh",
-        environment={"ENV_VAR": "window"},
-    )
-
-    assert any(
-        "Environment flag ignored" in record.msg for record in caplog.records
-    ), "Warning missing"
